==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/da_dk/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.category_added'] = 'Kategorien er blevet oprettet med succes.';
$lang['AdminMain.!success.category_updated'] = 'Kategorien er blevet opdateret med succes.';
$lang['AdminMain.!success.category_deleted'] = 'Kategorien er blevet slettet.';
$lang['AdminMain.!success.file_added'] = 'Filen er blevet tilføjet med succes.';
$lang['AdminMain.!success.file_updated'] = 'Filen er blevet opdateret med succes.';
$lang['AdminMain.!success.file_deleted'] = 'Filen er blevet slettet.';
$lang['AdminMain.!success.url_deleted'] = 'Den statiske URL er blevet slettet.';
$lang['AdminMain.!success.url_added'] = 'Den statiske URL er blevet tilføjet.';
$lang['AdminMain.!success.url_updated'] = 'Den statiske URL er blevet opdateret.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Indtast den absolutte sti til filen på filsystemet.';
$lang['AdminMain.!tooltip.category_type'] = 'URL\'en vil pege på den sidste fil, der blev uploadet til denne kategori.';
$lang['AdminMain.!text.root_directory'] = 'Hjemmekatalog';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.modal.delete_file'] = 'Er du sikker på, at du vil slette denne fil?';
$lang['AdminMain.modal.delete_category'] = 'Er du sikker på, at du vil slette denne kategori? Alle underkategorier og filer i denne kategori vil blive flyttet til den overordnede kategori.';
$lang['AdminMain.modal.delete_url'] = 'Er du sikker på, at du vil slette denne statiske URL?';
$lang['AdminMain.files.page_title'] = 'Download Manager > Administrer';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Download Manager';
$lang['AdminMain.files.tab_files'] = 'Filer';
$lang['AdminMain.files.tab_urls'] = 'Statiske webadresser';
$lang['AdminMain.files.add_download'] = 'Tilføj download her';
$lang['AdminMain.files.add_category'] = 'Tilføj kategori her';
$lang['AdminMain.files.go_back'] = 'Gå et niveau op';
$lang['AdminMain.files.edit'] = 'Rediger';
$lang['AdminMain.files.delete'] = 'Slet';
$lang['AdminMain.files.no_downloads'] = 'Der er ingen downloads i dette afsnit.';
$lang['AdminMain.urls.page_title'] = 'Download Manager > Administrer';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Download Manager';
$lang['AdminMain.urls.add_url'] = 'Tilføj statisk URL';
$lang['AdminMain.urls.tab_files'] = 'Filer';
$lang['AdminMain.urls.tab_urls'] = 'Statiske webadresser';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.heading_file'] = 'Fil';
$lang['AdminMain.urls.heading_link'] = 'Link';
$lang['AdminMain.urls.heading_options'] = 'Valgmuligheder';
$lang['AdminMain.urls.edit'] = 'Rediger';
$lang['AdminMain.urls.delete'] = 'Slet';
$lang['AdminMain.urls.latest_file'] = 'Seneste fil fra <strong>%1$s</strong>';
$lang['AdminMain.urls.no_urls'] = 'Der er ingen statiske URL\'er i denne sektion.';
$lang['AdminMain.add.page_title'] = 'Download Manager > Tilføj download';
$lang['AdminMain.add.boxtitle_root'] = 'Tilføj download til %1$s';
$lang['AdminMain.add.boxtitle_add'] = 'Tilføj download til kategori [%1$s].';
$lang['AdminMain.add.field_public'] = 'Offentligt tilgængelig';
$lang['AdminMain.add.field_logged_in'] = 'Skal være logget ind';
$lang['AdminMain.add.field_name'] = 'Navn';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Tilgængelig for kundegrupper';
$lang['AdminMain.add.field_available_to_packages'] = 'Tilgængelig for pakker';
$lang['AdminMain.add.text_clientgroups'] = 'Udvalgte kundegrupper';
$lang['AdminMain.add.text_packagegroups'] = 'Udvalgte pakker';
$lang['AdminMain.add.text_availableclientgroups'] = 'Tilgængelige kundegrupper';
$lang['AdminMain.add.text_availablepackages'] = 'Tilgængelige pakker';
$lang['AdminMain.add.field_upload'] = 'Upload fil';
$lang['AdminMain.add.field_path'] = 'Angiv sti til fil';
$lang['AdminMain.add.field_file'] = 'Fil';
$lang['AdminMain.add.field_file_name'] = 'Sti til fil';
$lang['AdminMain.add.submit_add'] = 'Tilføj download';
$lang['AdminMain.add.submit_cancel'] = 'Annuller';
$lang['AdminMain.addurl.page_title'] = 'Download Manager > Tilføj statisk URL';
$lang['AdminMain.addurl.boxtitle_add'] = 'Tilføj statisk URL';
$lang['AdminMain.addurl.field_url'] = 'URL-navn';
$lang['AdminMain.addurl.field_file'] = 'Fil';
$lang['AdminMain.addurl.field_category'] = 'Kategori';
$lang['AdminMain.addurl.submit_add'] = 'Tilføj URL';
$lang['AdminMain.addurl.submit_cancel'] = 'Annuller';
$lang['AdminMain.edit.page_title'] = 'Download Manager > Tilføj download';
$lang['AdminMain.edit.boxtitle_edit'] = 'Opdatering Download';
$lang['AdminMain.edit.field_public'] = 'Offentligt tilgængelig';
$lang['AdminMain.edit.field_logged_in'] = 'Skal være logget ind';
$lang['AdminMain.edit.field_name'] = 'Navn';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Tilgængelig for kundegrupper';
$lang['AdminMain.edit.field_available_to_packages'] = 'Tilgængelig for pakker';
$lang['AdminMain.edit.text_clientgroups'] = 'Udvalgte kundegrupper';
$lang['AdminMain.edit.text_packagegroups'] = 'Udvalgte pakker';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Tilgængelige kundegrupper';
$lang['AdminMain.edit.text_availablepackages'] = 'Tilgængelige pakker';
$lang['AdminMain.edit.field_upload'] = 'Upload fil';
$lang['AdminMain.edit.field_path'] = 'Angiv sti til fil';
$lang['AdminMain.edit.field_file'] = 'Fil';
$lang['AdminMain.edit.field_file_name'] = 'Sti til fil';
$lang['AdminMain.edit.submit_edit'] = 'Opdatering Download';
$lang['AdminMain.edit.submit_cancel'] = 'Annuller';
$lang['AdminMain.editurl.page_title'] = 'Download Manager > Rediger statisk URL';
$lang['AdminMain.editurl.boxtitle_add'] = 'Rediger statisk URL';
$lang['AdminMain.editurl.field_url'] = 'URL-navn';
$lang['AdminMain.editurl.field_file'] = 'Fil';
$lang['AdminMain.editurl.field_category'] = 'Kategori';
$lang['AdminMain.editurl.submit_add'] = 'Rediger URL';
$lang['AdminMain.editurl.submit_cancel'] = 'Annuller';
$lang['AdminMain.addcategory.page_title'] = 'Download Manager > Tilføj kategori';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Tilføj kategori til %1$s';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Tilføj kategori til kategori [%1$s].';
$lang['AdminMain.addcategory.field_name'] = 'Navn';
$lang['AdminMain.addcategory.field_description'] = 'Beskrivelse';
$lang['AdminMain.addcategory.submit_add'] = 'Opret kategori';
$lang['AdminMain.addcategory.submit_cancel'] = 'Annuller';
$lang['AdminMain.editcategory.page_title'] = 'Download Manager > Opdater kategori';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Opdater kategori [%1$s]';
$lang['AdminMain.editcategory.field_name'] = 'Navn';
$lang['AdminMain.editcategory.field_description'] = 'Beskrivelse';
$lang['AdminMain.editcategory.submit_edit'] = 'Opdater kategori';
$lang['AdminMain.editcategory.submit_cancel'] = 'Annuller';
$lang['AdminMain.package_name'] = '%1$s (%2$s)';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/da_dk/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.category_added'] = 'Kategorien er blevet oprettet med succes.';
$lang['AdminMain.!success.category_updated'] = 'Kategorien er blevet opdateret med succes.';
$lang['AdminMain.!success.category_deleted'] = 'Kategorien er blevet slettet.';
$lang['AdminMain.!success.file_added'] = 'Filen er blevet tilføjet med succes.';
$lang['AdminMain.!success.file_updated'] = 'Filen er blevet opdateret med succes.';
$lang['AdminMain.!success.file_deleted'] = 'Filen er blevet slettet.';
$lang['AdminMain.!success.url_deleted'] = 'Den statiske URL er blevet slettet.';
$lang['AdminMain.!success.url_added'] = 'Den statiske URL er blevet tilføjet.';
$lang['AdminMain.!success.url_updated'] = 'Den statiske URL er blevet opdateret.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Indtast den absolutte sti til filen på filsystemet.';
$lang['AdminMain.!tooltip.category_type'] = 'URL\'en vil pege på den sidste fil, der blev uploadet til denne kategori.';
$lang['AdminMain.!text.root_directory'] = 'Hjemmekatalog';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.modal.delete_file'] = 'Er du sikker på, at du vil slette denne fil?';
$lang['AdminMain.modal.delete_category'] = 'Er du sikker på, at du vil slette denne kategori? Alle underkategorier og filer i denne kategori vil blive flyttet til den overordnede kategori.';
$lang['AdminMain.modal.delete_url'] = 'Er du sikker på, at du vil slette denne statiske URL?';
$lang['AdminMain.files.page_title'] = 'Download Manager > Administrer';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Download Manager';
$lang['AdminMain.files.tab_files'] = 'Filer';
$lang['AdminMain.files.tab_urls'] = 'Statiske webadresser';
$lang['AdminMain.files.add_download'] = 'Tilføj download her';
$lang['AdminMain.files.add_category'] = 'Tilføj kategori her';
$lang['AdminMain.files.go_back'] = 'Gå et niveau op';
$lang['AdminMain.files.edit'] = 'Rediger';
$lang['AdminMain.files.delete'] = 'Slet';
$lang['AdminMain.files.no_downloads'] = 'Der er ingen downloads i dette afsnit.';
$lang['AdminMain.urls.page_title'] = 'Download Manager > Administrer';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Download Manager';
$lang['AdminMain.urls.add_url'] = 'Tilføj statisk URL';
$lang['AdminMain.urls.tab_files'] = 'Filer';
$lang['AdminMain.urls.tab_urls'] = 'Statiske webadresser';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.heading_file'] = 'Fil';
$lang['AdminMain.urls.heading_link'] = 'Link';
$lang['AdminMain.urls.heading_options'] = 'Valgmuligheder';
$lang['AdminMain.urls.edit'] = 'Rediger';
$lang['AdminMain.urls.delete'] = 'Slet';
$lang['AdminMain.urls.latest_file'] = 'Seneste fil fra <strong>%1$s</strong>';
$lang['AdminMain.urls.no_urls'] = 'Der er ingen statiske URL\'er i denne sektion.';
$lang['AdminMain.add.page_title'] = 'Download Manager > Tilføj download';
$lang['AdminMain.add.boxtitle_root'] = 'Tilføj download til %1$s';
$lang['AdminMain.add.boxtitle_add'] = 'Tilføj download til kategori [%1$s].';
$lang['AdminMain.add.field_public'] = 'Offentligt tilgængelig';
$lang['AdminMain.add.field_logged_in'] = 'Skal være logget ind';
$lang['AdminMain.add.field_name'] = 'Navn';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Tilgængelig for kundegrupper';
$lang['AdminMain.add.field_available_to_packages'] = 'Tilgængelig for pakker';
$lang['AdminMain.add.text_clientgroups'] = 'Udvalgte kundegrupper';
$lang['AdminMain.add.text_packagegroups'] = 'Udvalgte pakker';
$lang['AdminMain.add.text_availableclientgroups'] = 'Tilgængelige kundegrupper';
$lang['AdminMain.add.text_availablepackages'] = 'Tilgængelige pakker';
$lang['AdminMain.add.field_upload'] = 'Upload fil';
$lang['AdminMain.add.field_path'] = 'Angiv sti til fil';
$lang['AdminMain.add.field_file'] = 'Fil';
$lang['AdminMain.add.field_file_name'] = 'Sti til fil';
$lang['AdminMain.add.submit_add'] = 'Tilføj download';
$lang['AdminMain.add.submit_cancel'] = 'Annuller';
$lang['AdminMain.addurl.page_title'] = 'Download Manager > Tilføj statisk URL';
$lang['AdminMain.addurl.boxtitle_add'] = 'Tilføj statisk URL';
$lang['AdminMain.addurl.field_url'] = 'URL-navn';
$lang['AdminMain.addurl.field_file'] = 'Fil';
$lang['AdminMain.addurl.field_category'] = 'Kategori';
$lang['AdminMain.addurl.submit_add'] = 'Tilføj URL';
$lang['AdminMain.addurl.submit_cancel'] = 'Annuller';
$lang['AdminMain.edit.page_title'] = 'Download Manager > Tilføj download';
$lang['AdminMain.edit.boxtitle_edit'] = 'Opdatering Download';
$lang['AdminMain.edit.field_public'] = 'Offentligt tilgængelig';
$lang['AdminMain.edit.field_logged_in'] = 'Skal være logget ind';
$lang['AdminMain.edit.field_name'] = 'Navn';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Tilgængelig for kundegrupper';
$lang['AdminMain.edit.field_available_to_packages'] = 'Tilgængelig for pakker';
$lang['AdminMain.edit.text_clientgroups'] = 'Udvalgte kundegrupper';
$lang['AdminMain.edit.text_packagegroups'] = 'Udvalgte pakker';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Tilgængelige kundegrupper';
$lang['AdminMain.edit.text_availablepackages'] = 'Tilgængelige pakker';
$lang['AdminMain.edit.field_upload'] = 'Upload fil';
$lang['AdminMain.edit.field_path'] = 'Angiv sti til fil';
$lang['AdminMain.edit.field_file'] = 'Fil';
$lang['AdminMain.edit.field_file_name'] = 'Sti til fil';
$lang['AdminMain.edit.submit_edit'] = 'Opdatering Download';
$lang['AdminMain.edit.submit_cancel'] = 'Annuller';
$lang['AdminMain.editurl.page_title'] = 'Download Manager > Rediger statisk URL';
$lang['AdminMain.editurl.boxtitle_add'] = 'Rediger statisk URL';
$lang['AdminMain.editurl.field_url'] = 'URL-navn';
$lang['AdminMain.editurl.field_file'] = 'Fil';
$lang['AdminMain.editurl.field_category'] = 'Kategori';
$lang['AdminMain.editurl.submit_add'] = 'Rediger URL';
$lang['AdminMain.editurl.submit_cancel'] = 'Annuller';
$lang['AdminMain.addcategory.page_title'] = 'Download Manager > Tilføj kategori';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Tilføj kategori til %1$s';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Tilføj kategori til kategori [%1$s].';
$lang['AdminMain.addcategory.field_name'] = 'Navn';
$lang['AdminMain.addcategory.field_description'] = 'Beskrivelse';
$lang['AdminMain.addcategory.submit_add'] = 'Opret kategori';
$lang['AdminMain.addcategory.submit_cancel'] = 'Annuller';
$lang['AdminMain.editcategory.page_title'] = 'Download Manager > Opdater kategori';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Opdater kategori [%1$s]';
$lang['AdminMain.editcategory.field_name'] = 'Navn';
$lang['AdminMain.editcategory.field_description'] = 'Beskrivelse';
$lang['AdminMain.editcategory.submit_edit'] = 'Opdater kategori';
$lang['AdminMain.editcategory.submit_cancel'] = 'Annuller';
$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.edit.text_full_path'] = 'BEMÆRK: Filerne skal være placeret et sted i dit uploads-bibliotek: <strong>%1$s</strong>.';
$lang['AdminMain.add.text_full_path'] = 'BEMÆRK: Filerne skal være placeret et sted i dit uploads-bibliotek: <strong>%1$s</strong>.';
